@@ -8,6 +8,9 @@ use parking_lot::{Mutex, const_mutex, MutexGuard};
 
 use authproofs::*;
 
+#[path="sshkeys.rs"]
+pub mod sshkeys;
+
 //---------- simple types ----------
 
 slotmap::new_key_type!{
@@ -19,6 +22,7 @@ slotmap::new_key_type!{
 pub enum AccountScope {
   Server,
   Unix { user: String },
+  Ssh { user: String },
 }
 
 
@@ -46,6 +50,7 @@ pub struct AccountsGuard(MutexGuard<'static, Option<Accounts>>);
 pub struct Accounts {
   names: HashMap<Arc<AccountName>, AccountId>,
   records: DenseSlotMap<AccountId, AccountRecord>,
+  #[serde(default)] ssh_keys: sshkeys::Global,
 }
 
 #[derive(Serialize,Deserialize,Debug)]
@@ -55,6 +60,14 @@ pub struct AccountRecord {
   pub timezone: String,
   pub access: AccessRecord,
   pub layout: PresentationLayout,
+  #[serde(default)] // not relevant other than in entry for scope itself
+  pub ssh_keys: sshkeys::PerScope,
+}
+
+#[derive(Serialize,Deserialize,Debug)]
+pub struct AccountSshKey {
+  pub id: sshkeys::Id,
+  pub comment: sshkeys::Comment,
 }
 
 #[derive(Clone,Debug,Hash,Ord,PartialOrd,Eq,PartialEq)]
@@ -122,6 +135,13 @@ impl AccountScope {
       percent_encoding::NON_ALPHANUMERIC
       .remove(b'-');
 
+    let pct = |n, f: &mut F| {
+      for frag in utf8_percent_encode(n, &ENCODE) {
+        f(frag)?;
+      }
+      Ok::<_,E>(())
+    };
+
     match &self {
       AS::Server => {
         f("server")?;
@@ -131,12 +151,15 @@ impl AccountScope {
         f(":")?;
         f(user)?;
       }
+      AS::Ssh { user } => {
+        f("ssh")?;
+        f(":")?;
+        pct(user, &mut f)?;
+      }
     };
     for n in ns {
       f(":")?;
-      for frag in utf8_percent_encode(n, &ENCODE) {
-        f(frag)?;
-      }
+      pct(n, &mut f)?;
     }
   }
 
@@ -158,6 +181,10 @@ impl AccountScope {
           let user = next()?.to_owned();
           AccountScope::Unix { user }
         }
+        "ssh" => {
+          let user = next()?.to_owned();
+          AccountScope::Ssh { user }
+        }
         _ => {
           throw!(InvalidScopedName::UnknownScopeKind)
         }
@@ -187,6 +214,7 @@ impl AccountName {
     match &self.scope {
       AS::Server => "*SERVER*".into(),
       AS::Unix { user } => user.clone(),
+      AS::Ssh { user } => user.clone(),
     }
   }
 }
@@ -420,6 +448,13 @@ impl AccountsGuard {
     f.close()?;
     fs::rename(&tmp, &main)?;
   }
+
+  pub fn get(&self) -> &Accounts {
+    self.0.as_ref().expect("loaded")
+  }
+  pub fn get_mut(&mut self) -> &mut Accounts {
+    self.0.as_mut().expect("loaded")
+  }
 }
 
 //---------- load/save ----------
@@ -528,7 +563,7 @@ pub mod loaded_acl {
         } { continue }
         if needed & deny != 0 { break }
         if allow != 0 { needed &= !(allow | test_existence) }
-        if needed == 0 { return Authorisation::authorise_any() }
+        if needed == 0 { return Authorisation::promise_any() }
       }
       Err(if needed & test_existence != 0 {
         P::NOT_FOUND
