@@ -6,7 +6,7 @@ use crate::prelude::*;
 
 //---------- public types ----------
 
-pub use crate::prelude::Sha512Trunc256 as Digester;
+pub use crate::prelude::Sha512_256 as Digester;
 pub type DigestWrite<W> = crate::utils::DigestWrite<Digester, W>;
 
 #[derive(Copy,Clone,Hash,Eq,PartialEq,Serialize,Deserialize)]
@@ -29,7 +29,7 @@ pub struct Index(u16);
 #[derive(Serialize,Deserialize)]
 pub struct Id { pub index: Index, pub kind: Kind, }
 
-#[derive(Debug,Clone)]
+#[derive(Debug,Clone,Default)]
 pub struct InstanceBundles {
   bundles: Vec<Option<Note>>,
 }
@@ -312,6 +312,13 @@ impl Display for State {
   }
 }
 
+impl DebugIdentify for InstanceBundles {
+  #[throws(fmt::Error)]
+  fn debug_identify_type(f: &mut fmt::Formatter) {
+    write!(f, "InstanceBundles")?;
+  }
+}
+
 #[ext(pub)]
 impl MgmtBundleList {
   #[throws(IE)]
@@ -383,7 +390,6 @@ impl IndexedZip where {
       let sname = entry.name().to_owned();
       let uname = UniCase::new(sname.to_owned());
       if let Some(previously) = members.insert(uname, i) {
-        let sname = sname.to_owned();
         drop(entry);
         let previously = za.by_index_raw(previously)?;
         let previously = previously.name();
@@ -416,9 +422,11 @@ impl ZipArchive {
 
 impl<'z> IntoIterator for &'z IndexedZip {
   type Item = (&'z UniCase<String>, ZipIndex);
-  type IntoIter = impl Iterator<Item=Self::Item>;
+  type IntoIter = Box<dyn Iterator<Item=Self::Item> + 'z>;
   fn into_iter(self) -> Self::IntoIter {
-    self.members.iter().map(|(name,&index)| (name, ZipIndex(index)))
+    Box::new(
+      self.members.iter().map(|(name,&index)| (name, ZipIndex(index)))
+    ) as _
   }
 }
 
@@ -643,14 +651,14 @@ fn parse_bundle<EH>(id: Id, instance: &InstanceName,
 
   for LibScanned { libname, dir_inzip, inzip } in libs {
     eh.besteffort(|| Ok::<_,LE>({
-      let svg_dir = format!("{}/lib{:06}", id.path_dir(&instance), &inzip);
+      let svg_dir = format!("{}/lib{:06}", id.path_dir(instance), &inzip);
 
       let mut zf = za.i(inzip)?;
       let mut catalogue_data = String::new();
       zf.read_to_string(&mut catalogue_data)
         .map_err(|e| LE::badlib(&libname, &e))?;
       let mut src = LibraryInBundle {
-        catalogue_data: catalogue_data,
+        catalogue_data,
         svg_dir: &svg_dir,
         need_svgs: Vec::new(),
         id: &id,
@@ -803,7 +811,7 @@ fn usvg_size(f: &mut BufReader<File>) -> [f64;2] {
         );
 
         if let Ok(output) = size.iter().cloned()
-          .filter_map(|s|s)
+          .flatten()
           .collect::<ArrayVec<_,2>>()
           .into_inner() {
             break output;
@@ -915,7 +923,7 @@ pub fn spec_macroexpand(
 
   for (nomfile, data) in &templates { report(nomfile, data)?; }
 
-  let mut tera = tera_standalone::Tera::default();
+  let mut tera = Tera::default();
   tera.add_raw_templates(templates).context("load")?;
   let mut out: Vec<u8> = vec![];
   tera.render_to("spec", &default(), &mut out).context("render")?;
@@ -1018,11 +1026,7 @@ fn incorporate_bundle(ib: &mut InstanceBundles, ig: &mut Instance,
 }
 
 impl InstanceBundles {
-  pub fn new() -> Self {
-    InstanceBundles{
-      bundles: default(),
-    }
-  }
+  pub fn new() -> Self { default() }
 
   fn iter(&self) -> impl Iterator<Item=(Id, &State)> {
     self.bundles.iter().enumerate().filter_map(|(index, slot)| {
@@ -1056,7 +1060,7 @@ impl InstanceBundles {
       IE
       >>
   {
-    let bd = b_dir(&instance);
+    let bd = b_dir(instance);
     let mo = glob::MatchOptions {
       require_literal_leading_dot: true,
       ..default()
