@@ -30,9 +30,9 @@ pub struct ServerConfigSpec {
   pub command_socket: Option<String>,
   pub debug: Option<bool>,
   pub http_port: Option<u16>,
+  #[serde(default)] pub listen: Vec<SocketAddr>,
   pub public_url: String,
   pub sse_wildcard_url: Option<String>,
-  pub rocket_workers: Option<u16>,
   pub template_dir: Option<String>,
   pub nwtemplate_dir: Option<String>,
   pub wasm_dir: Option<String>,
@@ -64,10 +64,9 @@ pub struct ServerConfig {
   save_dir: String,
   pub command_socket: String,
   pub debug: bool,
-  pub http_port: Option<u16>,
+  pub listen: Vec<SocketAddr>,
   pub public_url: String,
   pub sse_wildcard_url: Option<(String, String)>,
-  pub rocket_workers: u16,
   pub template_dir: String,
   pub nwtemplate_dir: String,
   pub wasm_dir: String,
@@ -132,7 +131,7 @@ impl ServerConfigSpec {
                  -> Result<WholeServerConfig,AE> {
     let ServerConfigSpec {
       change_directory, base_dir, save_dir, command_socket, debug,
-      http_port, public_url, sse_wildcard_url, rocket_workers,
+      http_port, listen, public_url, sse_wildcard_url,
       template_dir, specs_dir, nwtemplate_dir, wasm_dir, libexec_dir, usvg_bin,
       log, bundled_sources, shapelibs, sendmail,
       debug_js_inject_file, check_bundled_sources, fake_rng,
@@ -143,13 +142,12 @@ impl ServerConfigSpec {
     let game_rng = fake_rng.make_game_rng();
     let home = || env::var("HOME").context("HOME");
 
-    let prctx;
-    if let Some(ref cd) = change_directory {
-      prctx = prmeth.chdir(cd)
+    let prctx = if let Some(ref cd) = change_directory {
+      prmeth.chdir(cd)
         .with_context(|| cd.clone())
-        .context("config change_directory")?;
+        .context("config change_directory")?
     } else {
-      prctx = PathResolveContext::Noop;
+      PathResolveContext::Noop
     };
 
     let defpath = |specd: Option<String>, leaf: &str| -> String {
@@ -234,8 +232,6 @@ impl ServerConfigSpec {
     }).transpose()?;
 
     let debug = debug.unwrap_or(cfg!(debug_assertions));
-    let rocket_workers = rocket_workers.unwrap_or(
-      if debug { 20 } else { 1000 });
 
     let log = {
       use toml::Value::Table;
@@ -254,7 +250,7 @@ impl ServerConfigSpec {
       // to toml and merging it with the stuff from the file.
       (||{
         if let Some(v) = env::var_os(LOG_ENV_VAR) {
-          let v = v.to_str().ok_or(anyhow!("UTF-8 conversion"))?;
+          let v = v.to_str().ok_or_else(|| anyhow!("UTF-8 conversion"))?;
           let v = LogSpecification::parse(v).context("parse")?;
           let mut buf: Vec<u8> = default();
           v.to_toml(&mut buf).context("convert to toml")?;
@@ -285,9 +281,26 @@ impl ServerConfigSpec {
 
     let check_bundled_sources = check_bundled_sources.unwrap_or(true); 
 
+    let listen = (! listen.is_empty()).then(|| listen);
+    let listen = match (listen, http_port) {
+      (Some(addrs), None) => addrs,
+      (Some(_), Some(_)) => throw!(anyhow!(
+        "both http_port and listen specified")),
+      (None, http_port) => {
+        let http_port = http_port.unwrap_or(8000);
+        let addrs: &[&dyn IpAddress] = &[
+          &Ipv6Addr::LOCALHOST,
+          &Ipv4Addr::LOCALHOST,
+        ];
+        addrs.iter()
+          .map(|addr| addr.with_port(http_port))
+          .collect()
+      },
+    };
+
     let server = ServerConfig {
       save_dir, command_socket, debug,
-      http_port, public_url, sse_wildcard_url, rocket_workers,
+      listen, public_url, sse_wildcard_url,
       template_dir, specs_dir, nwtemplate_dir, wasm_dir, libexec_dir,
       bundled_sources, shapelibs, sendmail, usvg_bin,
       debug_js_inject, check_bundled_sources, game_rng, prctx,
