@@ -258,15 +258,15 @@ const PRIVATE_Y: PrivateCaller = PrivateCaller(());
 
 // ========== implementations ==========
 
-impl RawTokenVal {
+impl<'s> From<&'s str> for &'s RawTokenVal {
   // str is [u8] with a funny hat on, so &str is pointer + byte count.
   // nomicon says &SomeStruct([T]) is pointer plus number of elements.
   // So &str and &SomeStruct(str) have the same layout
-  pub fn from_str(s: &str) -> &RawTokenVal { unsafe { mem::transmute(s) } }
+  fn from(s: &str) -> &RawTokenVal { unsafe { mem::transmute(s) } }
 }
 
 impl Borrow<RawTokenVal> for RawToken {
-  fn borrow(&self) -> &RawTokenVal { RawTokenVal::from_str(&self.0) }
+  fn borrow(&self) -> &RawTokenVal { (&*self.0).into() }
 }
 
 impl Debug for RawTokenVal {
@@ -399,7 +399,6 @@ impl Instance {
         .get(name)
         .ok_or(ME::GameNotFound)?
         .clone()
-        .into()
     )
   }
 
@@ -566,6 +565,24 @@ impl Display for InstanceName {
 }
 hformat_as_display!{InstanceName}
 
+impl DebugIdentify for InstanceContainer {
+  #[throws(fmt::Error)]
+  fn debug_identify(&self, f: &mut fmt::Formatter) {
+    write!(f, "InstanceContainer({})", &self.g.name)?;
+  }
+  #[throws(fmt::Error)]
+  fn debug_identify_type(f: &mut fmt::Formatter) {
+    write!(f, "InstanceContainer")?;
+  }
+}
+
+impl DebugIdentify for InstanceRef {
+  #[throws(fmt::Error)]
+  fn debug_identify_type(f: &mut fmt::Formatter) {
+    write!(f, "InstanceRef")?;
+  }
+}
+
 fn link_a_href(k: &HtmlStr, v: &str) -> Html {
   hformat!("<a href={}>{}</a>", v, k)
 }
@@ -622,7 +639,7 @@ impl<'ig> InstanceGuard<'ig> {
       Err(ME::AlreadyExists)?;
     }
     let player = self.c.g.gs.players.insert(gnew);
-    let u = PlayerUpdates::new_begin(&self.c.g.gs).new();
+    let u = PlayerUpdates::start(&self.c.g.gs).for_player();
     let record = PlayerRecord { u, account, ipl: inew, };
 
     self.c.g.iplayers.insert(player, record);
@@ -916,10 +933,10 @@ impl<'ig> InstanceGuard<'ig> {
     let gpl = self.c.g.gs.players.byid(player)?;
 
     let url = format!("{}/?{}",
-                      &config().public_url.trim_end_matches("/"),
+                      &config().public_url.trim_end_matches('/'),
                       token.0);
     let info = AccessTokenInfo { url };
-    let report = access.deliver(accounts, &self.c.g, &gpl, &ipl, info)?;
+    let report = access.deliver(accounts, &self.c.g, gpl, ipl, info)?;
     report
   }
 
@@ -1008,7 +1025,7 @@ enum SavefilenameParseResult {
 
 pub fn savefilename(name: &InstanceName, prefix: &str, suffix: &str)
                     -> String {
-  [ config().save_dir().as_str(), &"/", prefix ]
+  [ config().save_dir().as_str(), "/", prefix ]
     .iter().map(Deref::deref)
     .chain(iter::once( name.to_string().as_str() ))
     .chain([ suffix ].iter().map(Deref::deref))
@@ -1030,7 +1047,7 @@ fn savefilename_parse(leaf: &[u8]) -> SavefilenameParseResult {
   let rcomp = rhs.rsplitn(2, ':').next().unwrap();
   if rcomp.find('.').is_some() { return TempToDelete }
 
-  let name = InstanceName::from_str(&rhs)?;
+  let name = InstanceName::from_str(rhs)?;
 
   let aux_leaves = [ b"a-", b"b-" ].iter().map(|prefix| {
     let mut s: Vec<_> = (prefix[..]).into(); s.extend(after_ftype_prefix); s
@@ -1084,10 +1101,9 @@ impl InstanceGuard<'_> {
         let global_players = GLOBAL.players.read();
         s.c.g.tokens_players.tr
           .iter()
-          .map(|token|
+          .filter_map(|token|
                global_players.get(token)
                .map(|player| (token.0.as_str(), player.ident)))
-          .flatten()
           .collect()
       };
       let aplayers = s.c.g.iplayers.iter().map(
@@ -1153,13 +1169,13 @@ impl InstanceGuard<'_> {
     discard_mismatches(&mut gs.players,  &mut aplayers);
     discard_mismatches(&mut gs.pieces.0, &mut ipieces);
   
-    let pu_bc = PlayerUpdates::new_begin(&gs);
+    let pu_bc = PlayerUpdates::start(&gs);
 
     let iplayers: SecondarySlotMap<PlayerId, PlayerRecord> = {
       let a = aplayers;
       a.into_iter()
     }.filter_map(|(player, ipl)| {
-      let u = pu_bc.new();
+      let u = pu_bc.for_player();
       let account = accounts.lookup(ipl.acctid).ok()?.0.account.clone();
       Some((player, PlayerRecord { u, ipl, account }))
     }).collect();
@@ -1516,7 +1532,7 @@ fn client_expire_old_clients() {
         Some(())
       }
     }
-    if let (_, Some(())) = Any.iter(&gref, max_age) {
+    if let (_, Some(())) = Any.iter(gref, max_age) {
       expire.push(gref.clone());
     }
   }
