@@ -6,6 +6,7 @@ pub use otter_base;
 pub use otter_base::imports::*;
 
 pub use anyhow;
+pub use async_condvar_fair;
 pub use base64;
 pub use boolinator;
 pub use cast_trait_object;
@@ -13,9 +14,9 @@ pub use chrono;
 pub use chrono_tz;
 pub use delegate;
 pub use digest;
+pub use educe;
 pub use either;
 pub use env_logger;
-pub use failure;
 pub use flexi_logger;
 pub use fs2;
 pub use glob;
@@ -34,7 +35,7 @@ pub use regex;
 pub use rmp_serde;
 pub use sha2;
 pub use slotmap;
-pub use tera_standalone;
+pub use tera;
 pub use toml;
 pub use uds;
 pub use unicode_width;
