@@ -2,8 +2,21 @@
 // SPDX-License-Identifier: AGPL-3.0-or-later
 // There is NO WARRANTY.
 
-#![feature(min_type_alias_impl_trait)]
-#![allow(clippy::redundant_closure_call)]
+//! Otter game system; common infrastructure Rust crate.
+//!
+//! Otter, the Online Table Top Environment Renderer,
+//! is an online game system.
+//!
+//! <https://www.chiark.greenend.org.uk/~ianmdlvl/otter/docs/README.html>
+//!
+//! This crate is intended for use only by other parts of Otter.
+//!
+//! The command line client for joining and managing games is
+//! available via
+//! [`cargo install otter-cli`](https://lib.rs/crates/otter-cli)
+//!
+//! To run an Otter server, you will need to read the
+//! [build instructions](https://www.chiark.greenend.org.uk/~ianmdlvl/otter/docs/build.html).
 
 pub mod imports;
 pub mod prelude;
@@ -17,6 +30,7 @@ pub mod clock;
 pub mod commands;
 pub mod config;
 pub mod deck;
+pub mod debugmutex;
 pub mod debugreader;
 pub mod error;
 pub mod gamestate;
@@ -35,7 +49,6 @@ pub mod pieces;
 pub mod progress;
 pub mod shapelib;
 pub mod spec;
-pub mod sse;
 pub mod termprogress;
 pub mod timedfd;
 pub mod tz;
