@@ -347,10 +347,15 @@ impl Item {
 
   #[throws(IE)]
   fn describe_face(&self, face: FaceId) -> Html {
-    // When we are not occulted, we can show are true identity
-    // even if we have a back.
-    let face = self.faces.get(face).unwrap_or(&self.faces[0]);
-    self.descs[ face.desc ].clone()
+    self.descs[
+      if let Some(face) = self.faces.get(face) {
+        face.desc
+      } else if let Some(back) = &self.back {
+        return back.describe_html()?;
+      } else {
+        self.faces[0].desc
+      }
+    ].clone()
   }
 }
 
@@ -485,7 +490,7 @@ impl ItemSpec {
     let (lib, (item, idata)) = libs.iter().rev().find_map(
       |lib| Some((lib, lib.items.get_key_value(self.item.as_str())?))
     )
-      .ok_or(SpE::LibraryItemNotFound(self.clone()))?;
+      .ok_or_else(|| SpE::LibraryItemNotFound(self.clone()))?;
     lib.load1(idata, &self.lib, item.unnest::<str>(), ig, depth)?
   }
 
@@ -736,7 +741,7 @@ pub fn load_catalogue(libname: &str, src: &mut dyn LibrarySource) -> Contents {
     .as_table().ok_or_else(|| LLE::ExpectedTable(format!("group")))?;
   for (groupname, gdefn) in groups {
     let gdefn = resolve_inherit(INHERIT_DEPTH_LIMIT,
-                                &groups, groupname, gdefn)?;
+                                groups, groupname, gdefn)?;
     let gdefn: GroupDefn = TV::Table(gdefn.into_owned()).try_into()?;
     let d = GroupDetails {
       size: gdefn.d.size.iter().map(|s| s * gdefn.d.scale).collect(),
@@ -760,7 +765,7 @@ pub fn load_catalogue(libname: &str, src: &mut dyn LibrarySource) -> Contents {
         use SubstErrorKind as SEK;
         let err = |kind| SubstError { kind, input: before.to_string() };
         let mut matches = before.match_indices(needle);
-        let m1 = matches.next().ok_or(err(SEK::MissingToken(needle)))?;
+        let m1 = matches.next().ok_or_else(|| err(SEK::MissingToken(needle)))?;
         if matches.next().is_some() { Err(err(SEK::RepeatedToken(needle)))?; }
         let mut lhs = &before[0.. m1.0];
         let mut rhs = &before[m1.0 + m1.1.len() ..];
@@ -827,7 +832,7 @@ pub fn load_catalogue(libname: &str, src: &mut dyn LibrarySource) -> Contents {
         desc: &str
       | {
         let desc = if let Some(desc_template) = &group.d.desc_template {
-          subst(desc_template, "_desc", &desc)?.to_html()
+          subst(desc_template, "_desc", desc)?.to_html()
         } else {
           desc.to_html()
         };
@@ -862,7 +867,7 @@ pub fn load_catalogue(libname: &str, src: &mut dyn LibrarySource) -> Contents {
       } else {
         for (colour, recolourdata) in &group.d.colours {
           let t_sort = sort.as_ref().map(
-            |s| subst(&s, "_c", colour)).transpose()?;
+            |s| subst(s, "_c", colour)).transpose()?;
           let c_abbrev = &recolourdata.abbrev;
           let t_item_name = subst(item_name.as_str(), "_c", c_abbrev)?;
           let t_src_name = subst(&fe.src_file_spec, "_c", c_abbrev);
@@ -964,7 +969,7 @@ impl Config1 {
 }
 
 #[throws(LibraryLoadError)]
-pub fn load_global_libs(libs: &Vec<Config1>) {
+pub fn load_global_libs(libs: &[Config1]) {
   for l in libs {
     let libs = l.resolve()?;
     let n = libs.len();
@@ -1102,7 +1107,7 @@ impl TryFrom<String> for FileList {
     let mut xfields = Vec::new();
     for (lno,l) in s.lines().enumerate() {
       let l = l.trim();
-      if l=="" || l.starts_with("#") { continue }
+      if l=="" || l.starts_with('#') { continue }
       if let Some(xfields_spec) = l.strip_prefix(':') {
         if ! (o.is_empty() && xfields.is_empty()) {
           throw!(LLE::FilesListFieldsMustBeAtStart(lno));
@@ -1124,7 +1129,7 @@ impl TryFrom<String> for FileList {
       let item_spec = n()?;
       let src_file_spec = n()?;
       let extra_fields = xfields.iter()
-        .map(|field| Ok::<_,LLE>((field.to_owned(), n()?.to_owned())))
+        .map(|field| Ok::<_,LLE>((field.to_owned(), n()?)))
         .collect::<Result<_,_>>()?;
       let desc = remain.to_owned();
       o.push(FileData{ item_spec, src_file_spec, extra_fields, desc });
