@@ -6,6 +6,8 @@
 
 use crate::prelude::*;
 
+use std::ops::Neg;
+
 #[path="movehist.rs"] pub mod movehist;
 
 #[allow(non_camel_case_types)] type TUE_P<'u> = TransmitUpdateEntry_Piece<'u>;
@@ -14,6 +16,11 @@ use crate::prelude::*;
 
 // ---------- newtypes, type aliases, basic definitions ----------
 
+#[derive(Copy,Clone,Debug,Eq,PartialEq,Ord,PartialOrd)]
+#[derive(Serialize,Deserialize)]
+#[serde(transparent)]
+pub struct UpdateId(i64);
+
 pub type RawClientSequence = u64;
 
 #[derive(Debug,Copy,Clone,Eq,PartialEq,Deserialize,Serialize)]
@@ -37,7 +44,7 @@ pub struct ExecuteGameChangeUpdates {
 // ---------- prepared updates, queued in memory ----------
 
 pub type PlayerUpdatesLog =
-  StableIndexVecDeque<Arc<PreparedUpdate>,sse::UpdateId>;
+  StableIndexVecDeque<Arc<PreparedUpdate>,UpdateId>;
 
 #[derive(Debug)]
 pub struct PlayerUpdates {
@@ -141,25 +148,6 @@ pub struct DataLoadPlayer {
   nick: Html,
 }
 
-pub trait JsonLen {
-  fn json_len(&self) -> usize;
-}
-
-#[ext]
-impl<T:JsonLen> SecondarySlotMap<PlayerId, T> {
-  fn json_len(&self, player: PlayerId) -> usize {
-    if let Some(t) = self.get(player) {
-      50 + t.json_len()
-    } else {
-      50
-    }
-  }
-}
-
-impl JsonLen for Html {
-  fn json_len(&self) -> usize { self.as_html_str().as_bytes().len() }
-}
-
 // ---------- piece updates ----------
 
 #[derive(Debug,Clone,Copy,Serialize)]
@@ -337,14 +325,44 @@ pub fn log_did_to_piece(ioccults: &IOccults, goccults: &GameOccults,
   log_did_to_piece_whoby(ioccults,goccults,by_gpl,gpc,ipc,did)?.0
 }
 
+// ---------- support implementation ----------
+
+impl Neg for UpdateId {
+  type Output = Self;
+  fn neg(self) -> Self { UpdateId(-self.0) }
+}
+
+impl Display for UpdateId {
+  fn fmt(&self, f: &mut fmt::Formatter) -> Result<(), fmt::Error> {
+    Display::fmt(&self.0, f)
+  }
+}
+
+impl Bounded for UpdateId {
+  fn max_value() -> Self { UpdateId(Bounded::max_value()) }
+  fn min_value() -> Self { UpdateId(Bounded::min_value()) }
+}
+
+impl StableIndexOffset for UpdateId {
+  fn try_increment(&mut self) -> Option<()> { self.0.try_increment() }
+  fn try_decrement(&mut self) -> Option<()> { self.0.try_decrement() }
+  fn index_input(&self, input: Self) -> Option<usize> {
+    self.0.index_input(input.0)
+  }
+  fn index_output(&self, inner: usize) -> Option<Self> {
+    self.0.index_output(inner).map(UpdateId)
+  }
+  fn zero() -> Self { UpdateId(0) }
+}
+
 // ---------- prepared updates, queued in memory ----------
 
-pub struct PlayerUpdatesBuildContext {
+pub struct PlayerUpdatesStartContext {
   pub(self) u1: Arc<PreparedUpdate>,
 }
 
-impl PlayerUpdatesBuildContext {
-  pub fn new(&self) -> PlayerUpdates {
+impl PlayerUpdatesStartContext {
+  pub fn for_player(&self) -> PlayerUpdates {
     let mut log = StableIndexVecDeque::with_capacity(50);
     log.push_back(self.u1.clone());
     let cv = default();
@@ -353,13 +371,13 @@ impl PlayerUpdatesBuildContext {
 }
 
 impl PlayerUpdates {
-  pub fn new_begin(gs: &GameState) -> PlayerUpdatesBuildContext {
+  pub fn start(gs: &GameState) -> PlayerUpdatesStartContext {
     let u1 = Arc::new(PreparedUpdate {
       gen: gs.gen,
       when: Instant::now(),
       us: vec![],
     });
-    PlayerUpdatesBuildContext { u1 }
+    PlayerUpdatesStartContext { u1 }
   }
 
   pub fn push<U: Into<Arc<PreparedUpdate>>>(&mut self, update: U) {
@@ -387,105 +405,6 @@ impl PlayerUpdates {
   }
 }
 
-impl PreparedUpdate {
-  pub fn json_len(&self, player: PlayerId) -> usize {
-    self.us.iter().map(|u| 20 + u.json_len(player)).sum()
-  }
-}
-
-impl PreparedUpdateEntry_Piece {
-  pub fn json_len(&self, player: PlayerId) -> usize {
-    50 + self.ops.json_len(player)
-  }
-}
-
-impl<U:JsonLen> JsonLen for PreparedPieceUpdateGeneral<U> {
-  fn json_len(&self) -> usize { self.op.json_len() }
-}
-
-impl<NS:JsonLen, ZL> JsonLen for PieceUpdateOp<NS, ZL> {
-  fn json_len(&self) -> usize {
-    self.new_state().map(|x| x.json_len()).unwrap_or(0)
-  }
-}
-
-impl PreparedUpdateEntry_Image {
-  fn json_len(&self, player: PlayerId) -> usize {
-    self.ims.json_len(player)
-  }
-}
-
-impl JsonLen for PreparedPieceState {
-  fn json_len(&self) -> usize {
-    300 + self.svg.json_len() + self.uos.json_len()
-  }
-}
-
-impl JsonLen for PreparedPieceImage {
-  fn json_len(&self) -> usize {
-    100 + self.svg.json_len() + self.uos.json_len()
-  }
-}
-impl<T:JsonLen> JsonLen for Vec<T> {
-  fn json_len(&self) -> usize { self.iter().map(|x| x.json_len() + 10).sum() }
-}
-impl JsonLen for UoDescription {
-  fn json_len(&self) -> usize { self.desc.json_len() + 50 }
-}
-
-impl PreparedUpdateEntry {
-  pub fn json_len(&self, player: PlayerId) -> usize {
-    use PreparedUpdateEntry::*;
-    match self {
-      Piece(op) => {
-        op.json_len(player)
-      }
-      Image(ims) => {
-        ims.json_len(player)
-      }
-      MoveHistEnt(ents) => {
-        match ents.get(player) { None => 0, Some(_) => 100 }
-      }
-      Log(logent) => {
-        logent.logent.html.json_len() * 28
-      }
-      MoveHistClear => 50,
-      AddPlayer {
-        player:_,
-        data: DataLoadPlayer { dasharray, nick, },
-        new_info_pane,
-      } => {
-        dasharray.json_len() +
-        nick     .json_len() + 100
-          + new_info_pane.json_len()
-      }
-      RemovePlayer { player:_, new_info_pane } => {
-        new_info_pane.json_len() + 100
-      }
-      UpdateBundles { new_info_pane } => {
-        new_info_pane.json_len() + 100
-      }
-      SetTableColour(colour) => {
-        colour.json_len() + 50
-      }
-      SetLinks(links) => {
-        links.iter().filter_map(
-          |(_k,v)| Some(50 + v.as_ref()?.len())
-        ).sum::<usize>() + 50
-      }
-      Error(ESVU::PieceOpError { state, .. }) => {
-        100 + state.json_len(player)
-      }
-      Error(ESVU::InternalError) |
-      Error(ESVU::PlayerRemoved) |
-      Error(ESVU::TokenRevoked) |
-      SetTableSize(_) => {
-        100
-      }
-    }
-  }
-}
-
 impl DataLoadPlayer {
   pub fn from_player(ig: &Instance, player: PlayerId) -> Self {
     let gplayers = &ig.gs.players;
@@ -715,7 +634,6 @@ impl<'r> PrepareUpdatesBuffer<'r> {
         (Some(gpc), Some(ipc)) => {
           let pri = piece_pri(ioccults, &gs.occults, player,
                               gpl, piece, gpc, ipc);
-          drop(gpl);
           with_max_z(&mut gs.max_z, gpc);
           mk_update(ioccults,gs,gpc,ipc,player,&pri)?
         },
@@ -754,7 +672,7 @@ impl<'r> PrepareUpdatesBuffer<'r> {
             None => return Ok(None),
           }
         };
-        let u = Self::piece_update_player(ioccults,gs,gpc,ipc,ops,&pri)?;
+        let u = Self::piece_update_player(ioccults,gs,gpc,ipc,ops,pri)?;
         Ok::<_,IE>(u)
       },
 
@@ -936,7 +854,7 @@ impl PreparedUpdate {
           let zg = op.new_z_generation();
           TUE::Recorded { piece, cseq, zg, svg: ns.map(|ns| &ns.svg) }
         },
-        FTG::Piece => TUE::Piece(pue_piece_to_tue_p(&pue_p, player)?),
+        FTG::Piece => TUE::Piece(pue_piece_to_tue_p(pue_p, player)?),
         FTG::Exactly(x) => x,
       };
       Some(tue)
@@ -967,7 +885,7 @@ impl PreparedUpdate {
           TUE::MoveHistClear{}
         }
         PUE::Log(logent) => {
-          TUE::Log((&tz, &logent))
+          TUE::Log((tz, logent))
         }
         &PUE::SetTableSize(size) => {
           TUE::SetTableSize(size)
@@ -1011,7 +929,7 @@ impl PreparedUpdate {
                 match partially {
                   POEPP::Unprocessed => continue,
                   POEPP::Partially => {
-                    match pue_piece_to_tue(&state, player, dest) {
+                    match pue_piece_to_tue(state, player, dest) {
                       Some(tue) => tue,
                       None => continue,
                     }
@@ -1042,10 +960,10 @@ impl Vec<(PieceId, PieceUpdateOps)> {
   }
 }
 
-impl<'u> Into<FormattedLogEntry<'u>> for TransmitUpdateLogEntry<'u> {
-  fn into(self) -> FormattedLogEntry<'u> {
-    let (tz, logent) = self;
-    let when = logent.when.render(&tz);
+impl<'u> From<TransmitUpdateLogEntry<'u>> for FormattedLogEntry<'u> {
+  fn from(tule: TransmitUpdateLogEntry<'u>) -> FormattedLogEntry<'u> {
+    let (tz, logent) = tule;
+    let when = logent.when.render(tz);
     FormattedLogEntry { when, logent: &logent.logent }
   }
 }
