@@ -48,6 +48,7 @@ pub struct OldNew<T>([T; 2]);
 #[derive(Hash,Eq,PartialEq)]
 pub enum OldNewIndex { Old, New }
 
+#[allow(clippy::new_ret_no_self)]
 impl<T> OldNew<T> {
   pub fn old(&self) -> &T { &self.0[0] }
   pub fn new(&self) -> &T { &self.0[1] }
@@ -74,8 +75,9 @@ impl<T> OldNew<T> {
     self.0.iter()
   }
 
+  #[allow(clippy::should_implement_trait)] // yes, but, TAIT
   pub fn into_iter(self) -> impl Iterator<Item=T> {
-    std::array::IntoIter::new(self.0)
+    IntoIterator::into_iter(self.0)
   }
 }
 
@@ -187,13 +189,13 @@ pub mod timespec_serde {
 
   #[throws(S::Error)]
   pub fn serialize<S:Serializer>(v: &TimeSpec, s: S) -> S::Ok {
-    let v = Timespec(v.tv_sec().into(), v.tv_nsec().try_into().unwrap());
+    let v = Timespec(v.tv_sec(), v.tv_nsec().try_into().unwrap());
     Serialize::serialize(&v, s)?
   }
   #[throws(D::Error)]
   pub fn deserialize<'de, D:Deserializer<'de>>(d: D) -> TimeSpec {
     let Timespec(sec, nsec) = Deserialize::deserialize(d)?;
-    libc::timespec { tv_sec: sec.into(), tv_nsec: nsec.into() }.into()
+    libc::timespec { tv_sec: sec, tv_nsec: nsec.into() }.into()
   }
 }
 
@@ -266,62 +268,12 @@ macro_rules! deref_to_field_mut {
   }
 }
 
-#[derive(Debug)]
-pub enum Loop<E> {
-  Continue,
-  Break,
-  Error(E),
-}
-impl<E> From<E> for Loop<E> {
-  fn from(e: E) -> Loop<E> { Loop::Error(e) }
-}
-impl Loop<Infallible> {
-  pub fn ok<T>(t: T) -> Result<T,Loop<Infallible>> { Ok(t) }
-}
-
-pub trait IteratorExt<U,E,F>: Iterator
-  where F: FnMut(Self::Item) -> Result<U,Loop<E>>,
-{
-  type Return: Iterator<Item=U>;
-  fn map_loop(self, f: F) -> Self::Return where E: EmptyType;
-
-  type TryReturn: Iterator<Item=Result<U,E>>;
-  fn try_map_loop(self, f: F) -> Self::TryReturn;
-}
-
 pub trait EmptyType { fn diverge<T>(self) -> T; }
 
 impl EmptyType for Infallible {
   fn diverge<T>(self) -> T { match self { } }
 }
 
-impl<T,U,E,F> IteratorExt<U,E,F> for T where
-  T: Iterator,
-  F: FnMut(Self::Item) -> Result<U,Loop<E>>,
-{
-  type Return = impl Iterator<Item=U>;
-  fn map_loop(self, f: F) -> Self::Return where E: EmptyType {
-    self
-      .map(f)
-      .filter(|i| !matches!(i, Err(Loop::Continue)))
-      .take_while(|i| !matches!(i, Err(Loop::Break)))
-      .map(|i| i.ok().unwrap())
-  }
-
-  type TryReturn = impl Iterator<Item=Result<U,E>>;
-  fn try_map_loop(self, f: F) -> Self::TryReturn {
-    self
-      .map(f)
-      .filter(|i| matches!(i, Err(Loop::Continue)))
-      .take_while(|i| matches!(i, Err(Loop::Break)))
-      .map(|i| match i {
-        Ok(y) => Ok(y),
-        Err(Loop::Error(e)) => Err(e),
-        _ => panic!(),
-      })
-  }
-}
-
 #[macro_export] // <- otherwise bogus warning `unused_macros`
 macro_rules! matches_doesnot_yn2bool {
   (=) => (true);
@@ -417,7 +369,7 @@ macro_rules! want {
         want_failed_internal!{ $variant(_)=$input, x, $($d),* }
         None
       },
-    };
+    }
   );
   { $variant:ident = $input:expr } => {
     want!( $variant = $input,
@@ -515,11 +467,12 @@ impl<D: Digest, R: Read> Read for DigestRead<D, R> {
 }
 
 #[test]
+#[cfg(not(miri))]
 fn test_digest_read() {
   let ibuffer = b"abc";
-  let exp = Sha512Trunc256::digest(&ibuffer[..]);
+  let exp = Sha512_256::digest(&ibuffer[..]);
   let inner = &ibuffer[..];
-  let mut dr = DigestRead::<Sha512Trunc256,_>::new(inner);
+  let mut dr = DigestRead::<Sha512_256,_>::new(inner);
   let mut obuffer = [0;4];
   assert_eq!( dr.read(&mut obuffer).unwrap(), 3 );
   assert_eq!( &obuffer, b"abc\0" );
@@ -563,9 +516,10 @@ impl<D: Digest, W: Write> Write for DigestWrite<D, W> {
 }
 
 #[test]
+#[cfg(not(miri))]
 fn test_digest_write() {
   let ibuffer = b"xyz";
-  let exp = Sha512Trunc256::digest(&ibuffer[..]);
+  let exp = Sha512_256::digest(&ibuffer[..]);
   let mut obuffer = [0;4];
   let inner = &mut obuffer[..];
   let mut dw = bundles::DigestWrite::new(inner);
@@ -710,9 +664,11 @@ impl<W:Write> Write for SigPipeWriter<W> {
 }
 
 pub type RawStdout = SigPipeWriter<io::Stdout>;
+#[allow(clippy::new_without_default)] // Don't want these made willy-nilly
 impl RawStdout { pub fn new() -> Self { SigPipeWriter(io::stdout()) } }
 
 pub struct CookedStdout(pub BufWriter<SigPipeWriter<io::Stdout>>);
+#[allow(clippy::new_without_default)] // Don't want these made willy-nilly
 impl CookedStdout {
   pub fn new() -> Self { Self(BufWriter::new(RawStdout::new())) }
   fn handle_err(e: io::Error) -> ! {
@@ -736,6 +692,21 @@ impl Drop for CookedStdout {
   fn drop(&mut self) { self.must_flush() }
 }
 
+pub trait IpAddress: Debug {
+  fn with_port(&self, port: u16) -> SocketAddr;
+}
+
+impl<A> IpAddress for A where A: Into<IpAddr> + Debug + Clone {
+  fn with_port(&self, port: u16) -> SocketAddr {
+    match (self.clone().into(), port)
+      .to_socket_addrs()
+      .map(|i| i.at_most_one()) {
+        Ok(Ok(Some(addr))) => addr,
+        x => panic!("{:?},{} gave {:?}", self, port, x),
+      }
+  }
+}
+
 #[throws(fmt::Error)]
 pub fn fmt_hex(f: &mut Formatter, buf: &[u8]) {
   for v in buf { write!(f, "{:02x}", v)?; }
@@ -745,7 +716,7 @@ pub fn fmt_hex(f: &mut Formatter, buf: &[u8]) {
 #[must_use]
 pub fn parse_slice_hex(s: &str, buf: &mut [u8]) -> usize {
   let l = s.len();
-  if l % 1 != 0 { throw!() }
+  if l % 2 != 0 { throw!() }
   let l = l/2;
   if l > buf.len() { throw!() }
 
